// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

part of 'sign_in_cubit.dart';

/// {@template sign_in_state}
/// Sign in cubit state to manage the form.
/// {@endtemplate}
class SignInState extends FormDataState {
  /// {@macro sign_in_state}
  const SignInState({
    required super.form,
    super.status = FormStatus.pure,
    super.errorMessage,
  });

  /// Email validator of the form
  FormInputValidator<String?, ValidationError> get email =>
      form.validatorOf(AuthFormField.email);

  /// Password validator of the form
  FormInputValidator<String?, ValidationError> get password =>
      form.validatorOf(AuthFormField.password);

  SignInState copyWith({
    WyattForm? form,
    FormStatus? status,
    String? errorMessage,
  }) =>
      SignInState(
        form: form ?? this.form,
        status: status ?? this.status,
        errorMessage: errorMessage ?? this.errorMessage,
      );

  @override
  List<Object> get props => [email, password, status];

  @override
  String toString() => 'SignInState(status: ${status.name} '
      '${(errorMessage != null) ? " [$errorMessage]" : ""}, $form)';
}
