// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_component_copy_with_extension/wyatt_component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

part 'skill_card_component.g.dart';

@ComponentProxyExtension()
abstract class SkillCardComponent extends CardComponent
    with CopyWithMixin<$SkillCardComponentCWProxy> {
  const SkillCardComponent({
    this.axis,
    this.icons,
    this.title,
    this.subtitle,
    this.description,
    this.skills,
    this.bulletColors,
    this.bulletIcon,
    super.radius,
    super.padding,
    super.borderColors,
    super.backgroundColors,
    super.stroke,
    super.minSize,
    super.maxSize,
    super.shadow,
    super.titleStyle,
    super.subtitleStyle,
    super.bodyStyle,
    super.background,
    super.key,
  });

  /// Axis of the card
  ///
  /// If [axis] is [Axis.horizontal] then only the first icon will be displayed.
  /// Used in header of the card.
  final Axis? axis;

  /// Icons of the card
  ///
  /// If [axis] is [Axis.horizontal] then only the first icon will be displayed
  /// on the left side of the card and the rest will be ignored.
  final List<Widget>? icons;

  /// Title of the card
  final TextWrapper? title;

  /// Subtitle of the card
  final TextWrapper? subtitle;

  /// Description of the card
  final TextWrapper? description;

  /// Skills to be displayed
  final List<TextWrapper>? skills;

  /// Gradient of skill icons.
  final MultiColor? bulletColors;

  /// Icon to be displayed before each skill.
  final Widget? bulletIcon;
}
